@@ -1,11 +1,12 @@
 {
 
     package Acme::Mitey::Cards::Card;
+    our $USES_MITE = "Mite::Class";
     use strict;
     use warnings;
 
     sub new {
-        my $class = shift;
+        my $class = ref( $_[0] ) ? ref(shift) : shift;
         my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
         my $self  = bless {}, $class;
         my $args =
@@ -15,64 +16,76 @@
         my $no_build = delete $args->{__no_BUILD__};
 
         # Initialize attributes
-        if ( exists( $args->{q[deck]} ) ) {
+        if ( exists $args->{"deck"} ) {
             (
                 do {
                     use Scalar::Util ();
-                    Scalar::Util::blessed( $args->{q[deck]} )
-                      and $args->{q[deck]}->isa(q[Acme::Mitey::Cards::Deck]);
+                    Scalar::Util::blessed( $args->{"deck"} )
+                      and $args->{"deck"}->isa(q[Acme::Mitey::Cards::Deck]);
                 }
               )
               or require Carp
               && Carp::croak(
-q[Type check failed in constructor: deck should be InstanceOf["Acme::Mitey::Cards::Deck"]]
-              );
-            $self->{q[deck]} = $args->{q[deck]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "deck", "InstanceOf[\"Acme::Mitey::Cards::Deck\"]" );
+            $self->{"deck"} = $args->{"deck"};
         }
-        require Scalar::Util && Scalar::Util::weaken( $self->{q[deck]} );
-        if ( exists( $args->{q[reverse]} ) ) {
+        require Scalar::Util && Scalar::Util::weaken( $self->{"deck"} );
+        if ( exists $args->{"reverse"} ) {
             do {
 
                 package Acme::Mitey::Cards::Mite;
-                defined( $args->{q[reverse]} ) and do {
-                    ref( \$args->{q[reverse]} ) eq 'SCALAR'
-                      or ref( \( my $val = $args->{q[reverse]} ) ) eq 'SCALAR';
+                defined( $args->{"reverse"} ) and do {
+                    ref( \$args->{"reverse"} ) eq 'SCALAR'
+                      or ref( \( my $val = $args->{"reverse"} ) ) eq 'SCALAR';
                 }
               }
               or require Carp
               && Carp::croak(
-                q[Type check failed in constructor: reverse should be Str]);
-            $self->{q[reverse]} = $args->{q[reverse]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "reverse", "Str" );
+            $self->{"reverse"} = $args->{"reverse"};
         }
 
         # Enforce strict constructor
-        my @unknown = grep not(
-            do {
-
-                package Acme::Mitey::Cards::Mite;
-                ( defined and !ref and m{\A(?:(?:deck|reverse))\z} );
-            }
-          ),
-          keys %{$args};
+        my @unknown = grep not(/\A(?:deck|reverse)\z/), keys %{$args};
         @unknown
           and require Carp
           and Carp::croak(
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
-        !$no_build and @{ $meta->{BUILD} || [] } and $self->BUILDALL($args);
+        unless ($no_build) {
+            $_->( $self, $args ) for @{ $meta->{BUILD} || [] };
+        }
 
         return $self;
     }
 
-    sub BUILDALL {
-        $_->(@_) for @{ $Mite::META{ ref( $_[0] ) }{BUILD} || [] };
+    sub DESTROY {
+        my $self  = shift;
+        my $class = ref($self) || $self;
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        my $in_global_destruction =
+          defined ${^GLOBAL_PHASE}
+          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
+          : Devel::GlobalDestruction::in_global_destruction();
+        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
+            my $e = do {
+                local ( $?, $@ );
+                eval { $demolisher->( $self, $in_global_destruction ) };
+                $@;
+            };
+            no warnings 'misc';    # avoid (in cleanup) warnings
+            die $e if $e;          # rethrow
+        }
+        return;
     }
 
     sub __META__ {
         no strict 'refs';
-        require mro;
-        my $class      = shift;
+        my $class = shift;
+        $class = ref($class) || $class;
         my $linear_isa = mro::get_linear_isa($class);
         return {
             BUILD => [
@@ -81,20 +94,32 @@ q[Type check failed in constructor: deck should be InstanceOf["Acme::Mitey::Card
             ],
             DEMOLISH => [
                 map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } reverse @$linear_isa
+                  map { "$_\::DEMOLISH" } @$linear_isa
             ],
             HAS_BUILDARGS => $class->can('BUILDARGS'),
         };
     }
 
+    sub DOES {
+        my ( $self, $role ) = @_;
+        our %DOES;
+        return $DOES{$role} if exists $DOES{$role};
+        return 1            if $role eq __PACKAGE__;
+        return $self->SUPER::DOES($role);
+    }
+
+    sub does {
+        shift->DOES(@_);
+    }
+
     my $__XS = !$ENV{MITE_PURE_PERL}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for deck
     if ($__XS) {
         Class::XSAccessor->import(
-            chained => 1,
-            getters => { q[deck] => q[deck] },
+            chained   => 1,
+            "getters" => { "deck" => "deck" },
         );
     }
     else {
@@ -102,18 +127,18 @@ q[Type check failed in constructor: deck should be InstanceOf["Acme::Mitey::Card
             @_ > 1
               ? require Carp
               && Carp::croak("deck is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{q[deck]};
+              : $_[0]{"deck"};
         };
     }
 
     # Accessors for reverse
-    *reverse = sub {
+    sub reverse {
         @_ > 1
           ? require Carp
           && Carp::croak("reverse is a read-only attribute of @{[ref $_[0]]}")
           : (
-            exists( $_[0]{q[reverse]} ) ? $_[0]{q[reverse]} : (
-                $_[0]{q[reverse]} = do {
+            exists( $_[0]{"reverse"} ) ? $_[0]{"reverse"} : (
+                $_[0]{"reverse"} = do {
                     my $default_value = $_[0]->_build_reverse;
                     do {
 
@@ -127,14 +152,16 @@ q[Type check failed in constructor: deck should be InstanceOf["Acme::Mitey::Card
                       or do {
                         require Carp;
                         Carp::croak(
-q[Type check failed in default: reverse should be Str]
+                            sprintf
+                              "Type check failed in default: %s should be %s",
+                            "reverse", "Str"
                         );
                       };
                     $default_value;
                 }
             )
           );
-    };
+    }
 
     1;
 }
