@@ -1,6 +1,7 @@
 {
 
     package Acme::Mitey::Cards::Card::Numeric;
+    our $USES_MITE = "Mite::Class";
     use strict;
     use warnings;
 
@@ -9,11 +10,11 @@
 
         use mro 'c3';
         our @ISA;
-        push @ISA, q[Acme::Mitey::Cards::Card];
+        push @ISA, "Acme::Mitey::Cards::Card";
     }
 
     sub new {
-        my $class = shift;
+        my $class = ref( $_[0] ) ? ref(shift) : shift;
         my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
         my $self  = bless {}, $class;
         my $args =
@@ -23,72 +24,68 @@
         my $no_build = delete $args->{__no_BUILD__};
 
         # Initialize attributes
-        if ( exists( $args->{q[deck]} ) ) {
+        if ( exists $args->{"deck"} ) {
             (
                 do {
                     use Scalar::Util ();
-                    Scalar::Util::blessed( $args->{q[deck]} )
-                      and $args->{q[deck]}->isa(q[Acme::Mitey::Cards::Deck]);
+                    Scalar::Util::blessed( $args->{"deck"} )
+                      and $args->{"deck"}->isa(q[Acme::Mitey::Cards::Deck]);
                 }
               )
               or require Carp
               && Carp::croak(
-q[Type check failed in constructor: deck should be InstanceOf["Acme::Mitey::Cards::Deck"]]
-              );
-            $self->{q[deck]} = $args->{q[deck]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "deck", "InstanceOf[\"Acme::Mitey::Cards::Deck\"]" );
+            $self->{"deck"} = $args->{"deck"};
         }
-        require Scalar::Util && Scalar::Util::weaken( $self->{q[deck]} );
-        if ( exists( $args->{q[number]} ) ) {
+        require Scalar::Util && Scalar::Util::weaken( $self->{"deck"} );
+        if ( exists $args->{"number"} ) {
             (
                 do {
-                    my $tmp = $args->{q[number]};
+                    my $tmp = $args->{"number"};
                     defined($tmp) and !ref($tmp) and $tmp =~ /\A-?[0-9]+\z/;
                 }
               )
               or require Carp
               && Carp::croak(
-                q[Type check failed in constructor: number should be Int]);
-            $self->{q[number]} = $args->{q[number]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "number", "Int" );
+            $self->{"number"} = $args->{"number"};
         }
         else { require Carp; Carp::croak("Missing key in constructor: number") }
-        if ( exists( $args->{q[reverse]} ) ) {
+        if ( exists $args->{"reverse"} ) {
             do {
 
                 package Acme::Mitey::Cards::Mite;
-                defined( $args->{q[reverse]} ) and do {
-                    ref( \$args->{q[reverse]} ) eq 'SCALAR'
-                      or ref( \( my $val = $args->{q[reverse]} ) ) eq 'SCALAR';
+                defined( $args->{"reverse"} ) and do {
+                    ref( \$args->{"reverse"} ) eq 'SCALAR'
+                      or ref( \( my $val = $args->{"reverse"} ) ) eq 'SCALAR';
                 }
               }
               or require Carp
               && Carp::croak(
-                q[Type check failed in constructor: reverse should be Str]);
-            $self->{q[reverse]} = $args->{q[reverse]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "reverse", "Str" );
+            $self->{"reverse"} = $args->{"reverse"};
         }
-        if ( exists( $args->{q[suit]} ) ) {
+        if ( exists $args->{"suit"} ) {
             (
                 do {
                     use Scalar::Util ();
-                    Scalar::Util::blessed( $args->{q[suit]} )
-                      and $args->{q[suit]}->isa(q[Acme::Mitey::Cards::Suit]);
+                    Scalar::Util::blessed( $args->{"suit"} )
+                      and $args->{"suit"}->isa(q[Acme::Mitey::Cards::Suit]);
                 }
               )
               or require Carp
               && Carp::croak(
-q[Type check failed in constructor: suit should be InstanceOf["Acme::Mitey::Cards::Suit"]]
-              );
-            $self->{q[suit]} = $args->{q[suit]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "suit", "InstanceOf[\"Acme::Mitey::Cards::Suit\"]" );
+            $self->{"suit"} = $args->{"suit"};
         }
         else { require Carp; Carp::croak("Missing key in constructor: suit") }
 
         # Enforce strict constructor
-        my @unknown = grep not(
-            do {
-
-                package Acme::Mitey::Cards::Mite;
-                ( defined and !ref and m{\A(?:(?:deck|number|reverse|suit))\z} );
-            }
-          ),
+        my @unknown = grep not(/\A(?:deck|number|reverse|suit)\z/),
           keys %{$args};
         @unknown
           and require Carp
@@ -96,19 +93,37 @@ q[Type check failed in constructor: suit should be InstanceOf["Acme::Mitey::Card
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
-        !$no_build and @{ $meta->{BUILD} || [] } and $self->BUILDALL($args);
+        unless ($no_build) {
+            $_->( $self, $args ) for @{ $meta->{BUILD} || [] };
+        }
 
         return $self;
     }
 
-    sub BUILDALL {
-        $_->(@_) for @{ $Mite::META{ ref( $_[0] ) }{BUILD} || [] };
+    sub DESTROY {
+        my $self  = shift;
+        my $class = ref($self) || $self;
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        my $in_global_destruction =
+          defined ${^GLOBAL_PHASE}
+          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
+          : Devel::GlobalDestruction::in_global_destruction();
+        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
+            my $e = do {
+                local ( $?, $@ );
+                eval { $demolisher->( $self, $in_global_destruction ) };
+                $@;
+            };
+            no warnings 'misc';    # avoid (in cleanup) warnings
+            die $e if $e;          # rethrow
+        }
+        return;
     }
 
     sub __META__ {
         no strict 'refs';
-        require mro;
-        my $class      = shift;
+        my $class = shift;
+        $class = ref($class) || $class;
         my $linear_isa = mro::get_linear_isa($class);
         return {
             BUILD => [
@@ -117,20 +132,32 @@ q[Type check failed in constructor: suit should be InstanceOf["Acme::Mitey::Card
             ],
             DEMOLISH => [
                 map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } reverse @$linear_isa
+                  map { "$_\::DEMOLISH" } @$linear_isa
             ],
             HAS_BUILDARGS => $class->can('BUILDARGS'),
         };
     }
 
+    sub DOES {
+        my ( $self, $role ) = @_;
+        our %DOES;
+        return $DOES{$role} if exists $DOES{$role};
+        return 1            if $role eq __PACKAGE__;
+        return $self->SUPER::DOES($role);
+    }
+
+    sub does {
+        shift->DOES(@_);
+    }
+
     my $__XS = !$ENV{MITE_PURE_PERL}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for number
     if ($__XS) {
         Class::XSAccessor->import(
-            chained => 1,
-            getters => { q[number] => q[number] },
+            chained   => 1,
+            "getters" => { "number" => "number" },
         );
     }
     else {
@@ -138,15 +165,15 @@ q[Type check failed in constructor: suit should be InstanceOf["Acme::Mitey::Card
             @_ > 1
               ? require Carp && Carp::croak(
                 "number is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{q[number]};
+              : $_[0]{"number"};
         };
     }
 
     # Accessors for suit
     if ($__XS) {
         Class::XSAccessor->import(
-            chained => 1,
-            getters => { q[suit] => q[suit] },
+            chained   => 1,
+            "getters" => { "suit" => "suit" },
         );
     }
     else {
@@ -154,7 +181,7 @@ q[Type check failed in constructor: suit should be InstanceOf["Acme::Mitey::Card
             @_ > 1
               ? require Carp
               && Carp::croak("suit is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{q[suit]};
+              : $_[0]{"suit"};
         };
     }
 
