@@ -1,6 +1,6 @@
 package Acme::Mitey::Cards::Deck;
 
-our $VERSION   = '0.005';
+our $VERSION   = '0.006';
 our $AUTHORITY = 'cpan:TOBYINK';
 
 use Acme::Mitey::Cards::Mite;
@@ -80,7 +80,7 @@ sub discard_jokers {
 sub deal_hand {
 	my ( $self, %args ) = ( shift, @_ );
 
-	my $n = delete( $args{count} ) // 7;
+	my $n = defined( $args{count} ) ? delete( $args{count} ) : 7;
 	croak "Not enough cards" if $n > $self->count;
 
 	my $took = $self->take( $n );
