@@ -1,6 +1,7 @@
 {
 
     package Acme::Mitey::Cards::Deck;
+    our $USES_MITE = "Mite::Class";
     use strict;
     use warnings;
 
@@ -9,11 +10,11 @@
 
         use mro 'c3';
         our @ISA;
-        push @ISA, q[Acme::Mitey::Cards::Set];
+        push @ISA, "Acme::Mitey::Cards::Set";
     }
 
     sub new {
-        my $class = shift;
+        my $class = ref( $_[0] ) ? ref(shift) : shift;
         my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
         my $self  = bless {}, $class;
         my $args =
@@ -23,16 +24,16 @@
         my $no_build = delete $args->{__no_BUILD__};
 
         # Initialize attributes
-        if ( exists( $args->{q[cards]} ) ) {
+        if ( exists $args->{"cards"} ) {
             (
                 do {
 
                     package Acme::Mitey::Cards::Mite;
-                    ref( $args->{q[cards]} ) eq 'ARRAY';
+                    ref( $args->{"cards"} ) eq 'ARRAY';
                   }
                   and do {
                     my $ok = 1;
-                    for my $i ( @{ $args->{q[cards]} } ) {
+                    for my $i ( @{ $args->{"cards"} } ) {
                         ( $ok = 0, last )
                           unless (
                             do {
@@ -47,20 +48,20 @@
               )
               or require Carp
               && Carp::croak(
-q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::Mitey::Cards::Card"]]]
-              );
-            $self->{q[cards]} = $args->{q[cards]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "cards", "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]" );
+            $self->{"cards"} = $args->{"cards"};
         }
-        if ( exists( $args->{q[original_cards]} ) ) {
+        if ( exists $args->{"original_cards"} ) {
             (
                 do {
 
                     package Acme::Mitey::Cards::Mite;
-                    ref( $args->{q[original_cards]} ) eq 'ARRAY';
+                    ref( $args->{"original_cards"} ) eq 'ARRAY';
                   }
                   and do {
                     my $ok = 1;
-                    for my $i ( @{ $args->{q[original_cards]} } ) {
+                    for my $i ( @{ $args->{"original_cards"} } ) {
                         ( $ok = 0, last )
                           unless (
                             do {
@@ -73,25 +74,27 @@ q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::M
                     $ok;
                 }
               )
-              or require Carp
-              && Carp::croak(
-q[Type check failed in constructor: original_cards should be ArrayRef[InstanceOf["Acme::Mitey::Cards::Card"]]]
+              or require Carp && Carp::croak(
+                sprintf "Type check failed in constructor: %s should be %s",
+                "original_cards",
+                "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]"
               );
-            $self->{q[original_cards]} = $args->{q[original_cards]};
+            $self->{"original_cards"} = $args->{"original_cards"};
         }
-        if ( exists( $args->{q[reverse]} ) ) {
+        if ( exists $args->{"reverse"} ) {
             do {
 
                 package Acme::Mitey::Cards::Mite;
-                defined( $args->{q[reverse]} ) and do {
-                    ref( \$args->{q[reverse]} ) eq 'SCALAR'
-                      or ref( \( my $val = $args->{q[reverse]} ) ) eq 'SCALAR';
+                defined( $args->{"reverse"} ) and do {
+                    ref( \$args->{"reverse"} ) eq 'SCALAR'
+                      or ref( \( my $val = $args->{"reverse"} ) ) eq 'SCALAR';
                 }
               }
               or require Carp
               && Carp::croak(
-                q[Type check failed in constructor: reverse should be Str]);
-            $self->{q[reverse]} = $args->{q[reverse]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "reverse", "Str" );
+            $self->{"reverse"} = $args->{"reverse"};
         }
         else {
             my $value = do {
@@ -107,23 +110,17 @@ q[Type check failed in constructor: original_cards should be ArrayRef[InstanceOf
                   or do {
                     require Carp;
                     Carp::croak(
-                        q[Type check failed in default: reverse should be Str]);
+                        sprintf "Type check failed in default: %s should be %s",
+                        "reverse", "Str"
+                    );
                   };
                 $default_value;
             };
-            $self->{q[reverse]} = $value;
+            $self->{"reverse"} = $value;
         }
 
         # Enforce strict constructor
-        my @unknown = grep not(
-            do {
-
-                package Acme::Mitey::Cards::Mite;
-                (         defined
-                      and !ref
-                      and m{\A(?:(?:cards|original_cards|reverse))\z} );
-            }
-          ),
+        my @unknown = grep not(/\A(?:cards|original_cards|reverse)\z/),
           keys %{$args};
         @unknown
           and require Carp
@@ -131,19 +128,37 @@ q[Type check failed in constructor: original_cards should be ArrayRef[InstanceOf
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
-        !$no_build and @{ $meta->{BUILD} || [] } and $self->BUILDALL($args);
+        unless ($no_build) {
+            $_->( $self, $args ) for @{ $meta->{BUILD} || [] };
+        }
 
         return $self;
     }
 
-    sub BUILDALL {
-        $_->(@_) for @{ $Mite::META{ ref( $_[0] ) }{BUILD} || [] };
+    sub DESTROY {
+        my $self  = shift;
+        my $class = ref($self) || $self;
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        my $in_global_destruction =
+          defined ${^GLOBAL_PHASE}
+          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
+          : Devel::GlobalDestruction::in_global_destruction();
+        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
+            my $e = do {
+                local ( $?, $@ );
+                eval { $demolisher->( $self, $in_global_destruction ) };
+                $@;
+            };
+            no warnings 'misc';    # avoid (in cleanup) warnings
+            die $e if $e;          # rethrow
+        }
+        return;
     }
 
     sub __META__ {
         no strict 'refs';
-        require mro;
-        my $class      = shift;
+        my $class = shift;
+        $class = ref($class) || $class;
         my $linear_isa = mro::get_linear_isa($class);
         return {
             BUILD => [
@@ -152,22 +167,34 @@ q[Type check failed in constructor: original_cards should be ArrayRef[InstanceOf
             ],
             DEMOLISH => [
                 map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } reverse @$linear_isa
+                  map { "$_\::DEMOLISH" } @$linear_isa
             ],
             HAS_BUILDARGS => $class->can('BUILDARGS'),
         };
     }
 
+    sub DOES {
+        my ( $self, $role ) = @_;
+        our %DOES;
+        return $DOES{$role} if exists $DOES{$role};
+        return 1            if $role eq __PACKAGE__;
+        return $self->SUPER::DOES($role);
+    }
+
+    sub does {
+        shift->DOES(@_);
+    }
+
     my $__XS = !$ENV{MITE_PURE_PERL}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for original_cards
-    *original_cards = sub {
+    sub original_cards {
         @_ > 1 ? require Carp
           && Carp::croak(
             "original_cards is a read-only attribute of @{[ref $_[0]]}") : (
-            exists( $_[0]{q[original_cards]} ) ? $_[0]{q[original_cards]} : (
-                $_[0]{q[original_cards]} = do {
+            exists( $_[0]{"original_cards"} ) ? $_[0]{"original_cards"} : (
+                $_[0]{"original_cards"} = do {
                     my $default_value = $_[0]->_build_original_cards;
                     do {
 
@@ -191,20 +218,23 @@ q[Type check failed in constructor: original_cards should be ArrayRef[InstanceOf
                       or do {
                         require Carp;
                         Carp::croak(
-q[Type check failed in default: original_cards should be ArrayRef[InstanceOf["Acme::Mitey::Cards::Card"]]]
+                            sprintf
+                              "Type check failed in default: %s should be %s",
+                            "original_cards",
+                            "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]"
                         );
                       };
                     $default_value;
                 }
             )
             );
-    };
+    }
 
     # Accessors for reverse
     if ($__XS) {
         Class::XSAccessor->import(
-            chained => 1,
-            getters => { q[reverse] => q[reverse] },
+            chained   => 1,
+            "getters" => { "reverse" => "reverse" },
         );
     }
     else {
@@ -212,7 +242,7 @@ q[Type check failed in default: original_cards should be ArrayRef[InstanceOf["Ac
             @_ > 1
               ? require Carp && Carp::croak(
                 "reverse is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{q[reverse]};
+              : $_[0]{"reverse"};
         };
     }
 
