@@ -1,6 +1,7 @@
 {
 
     package Acme::Mitey::Cards::Hand;
+    our $USES_MITE = "Mite::Class";
     use strict;
     use warnings;
 
@@ -9,11 +10,11 @@
 
         use mro 'c3';
         our @ISA;
-        push @ISA, q[Acme::Mitey::Cards::Set];
+        push @ISA, "Acme::Mitey::Cards::Set";
     }
 
     sub new {
-        my $class = shift;
+        my $class = ref( $_[0] ) ? ref(shift) : shift;
         my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
         my $self  = bless {}, $class;
         my $args =
@@ -23,16 +24,16 @@
         my $no_build = delete $args->{__no_BUILD__};
 
         # Initialize attributes
-        if ( exists( $args->{q[cards]} ) ) {
+        if ( exists $args->{"cards"} ) {
             (
                 do {
 
                     package Acme::Mitey::Cards::Mite;
-                    ref( $args->{q[cards]} ) eq 'ARRAY';
+                    ref( $args->{"cards"} ) eq 'ARRAY';
                   }
                   and do {
                     my $ok = 1;
-                    for my $i ( @{ $args->{q[cards]} } ) {
+                    for my $i ( @{ $args->{"cards"} } ) {
                         ( $ok = 0, last )
                           unless (
                             do {
@@ -47,11 +48,11 @@
               )
               or require Carp
               && Carp::croak(
-q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::Mitey::Cards::Card"]]]
-              );
-            $self->{q[cards]} = $args->{q[cards]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "cards", "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]" );
+            $self->{"cards"} = $args->{"cards"};
         }
-        if ( exists( $args->{q[owner]} ) ) {
+        if ( exists $args->{"owner"} ) {
             do {
 
                 package Acme::Mitey::Cards::Mite;
@@ -59,9 +60,9 @@ q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::M
                     do {
 
                         package Acme::Mitey::Cards::Mite;
-                        defined( $args->{q[owner]} ) and do {
-                            ref( \$args->{q[owner]} ) eq 'SCALAR'
-                              or ref( \( my $val = $args->{q[owner]} ) ) eq
+                        defined( $args->{"owner"} ) and do {
+                            ref( \$args->{"owner"} ) eq 'SCALAR'
+                              or ref( \( my $val = $args->{"owner"} ) ) eq
                               'SCALAR';
                         }
                       }
@@ -70,46 +71,57 @@ q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::M
 
                             package Acme::Mitey::Cards::Mite;
                             use Scalar::Util ();
-                            Scalar::Util::blessed( $args->{q[owner]} );
+                            Scalar::Util::blessed( $args->{"owner"} );
                         }
                       )
                 );
               }
               or require Carp
               && Carp::croak(
-                q[Type check failed in constructor: owner should be Str|Object]
-              );
-            $self->{q[owner]} = $args->{q[owner]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "owner", "Str|Object" );
+            $self->{"owner"} = $args->{"owner"};
         }
 
         # Enforce strict constructor
-        my @unknown = grep not(
-            do {
-
-                package Acme::Mitey::Cards::Mite;
-                ( defined and !ref and m{\A(?:(?:cards|owner))\z} );
-            }
-          ),
-          keys %{$args};
+        my @unknown = grep not(/\A(?:cards|owner)\z/), keys %{$args};
         @unknown
           and require Carp
           and Carp::croak(
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
-        !$no_build and @{ $meta->{BUILD} || [] } and $self->BUILDALL($args);
+        unless ($no_build) {
+            $_->( $self, $args ) for @{ $meta->{BUILD} || [] };
+        }
 
         return $self;
     }
 
-    sub BUILDALL {
-        $_->(@_) for @{ $Mite::META{ ref( $_[0] ) }{BUILD} || [] };
+    sub DESTROY {
+        my $self  = shift;
+        my $class = ref($self) || $self;
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        my $in_global_destruction =
+          defined ${^GLOBAL_PHASE}
+          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
+          : Devel::GlobalDestruction::in_global_destruction();
+        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
+            my $e = do {
+                local ( $?, $@ );
+                eval { $demolisher->( $self, $in_global_destruction ) };
+                $@;
+            };
+            no warnings 'misc';    # avoid (in cleanup) warnings
+            die $e if $e;          # rethrow
+        }
+        return;
     }
 
     sub __META__ {
         no strict 'refs';
-        require mro;
-        my $class      = shift;
+        my $class = shift;
+        $class = ref($class) || $class;
         my $linear_isa = mro::get_linear_isa($class);
         return {
             BUILD => [
@@ -118,17 +130,29 @@ q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::M
             ],
             DEMOLISH => [
                 map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } reverse @$linear_isa
+                  map { "$_\::DEMOLISH" } @$linear_isa
             ],
             HAS_BUILDARGS => $class->can('BUILDARGS'),
         };
     }
 
+    sub DOES {
+        my ( $self, $role ) = @_;
+        our %DOES;
+        return $DOES{$role} if exists $DOES{$role};
+        return 1            if $role eq __PACKAGE__;
+        return $self->SUPER::DOES($role);
+    }
+
+    sub does {
+        shift->DOES(@_);
+    }
+
     my $__XS = !$ENV{MITE_PURE_PERL}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for owner
-    *owner = sub {
+    sub owner {
         @_ > 1
           ? do {
             do {
@@ -155,12 +179,13 @@ q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::M
               }
               or require Carp
               && Carp::croak(
-                q[Type check failed in accessor: value should be Str|Object]);
-            $_[0]{q[owner]} = $_[1];
+                sprintf "Type check failed in %s: value should be %s",
+                "accessor", "Str|Object" );
+            $_[0]{"owner"} = $_[1];
             $_[0];
           }
-          : ( $_[0]{q[owner]} );
-    };
+          : ( $_[0]{"owner"} );
+    }
 
     1;
 }
