@@ -1,11 +1,12 @@
 {
 
     package Acme::Mitey::Cards::Set;
+    our $USES_MITE = "Mite::Class";
     use strict;
     use warnings;
 
     sub new {
-        my $class = shift;
+        my $class = ref( $_[0] ) ? ref(shift) : shift;
         my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
         my $self  = bless {}, $class;
         my $args =
@@ -15,16 +16,16 @@
         my $no_build = delete $args->{__no_BUILD__};
 
         # Initialize attributes
-        if ( exists( $args->{q[cards]} ) ) {
+        if ( exists $args->{"cards"} ) {
             (
                 do {
 
                     package Acme::Mitey::Cards::Mite;
-                    ref( $args->{q[cards]} ) eq 'ARRAY';
+                    ref( $args->{"cards"} ) eq 'ARRAY';
                   }
                   and do {
                     my $ok = 1;
-                    for my $i ( @{ $args->{q[cards]} } ) {
+                    for my $i ( @{ $args->{"cards"} } ) {
                         ( $ok = 0, last )
                           unless (
                             do {
@@ -39,39 +40,50 @@
               )
               or require Carp
               && Carp::croak(
-q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::Mitey::Cards::Card"]]]
-              );
-            $self->{q[cards]} = $args->{q[cards]};
+                sprintf "Type check failed in constructor: %s should be %s",
+                "cards", "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]" );
+            $self->{"cards"} = $args->{"cards"};
         }
 
         # Enforce strict constructor
-        my @unknown = grep not(
-            do {
-
-                package Acme::Mitey::Cards::Mite;
-                ( defined and !ref and m{\A(?:cards)\z} );
-            }
-          ),
-          keys %{$args};
+        my @unknown = grep not(/\Acards\z/), keys %{$args};
         @unknown
           and require Carp
           and Carp::croak(
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
-        !$no_build and @{ $meta->{BUILD} || [] } and $self->BUILDALL($args);
+        unless ($no_build) {
+            $_->( $self, $args ) for @{ $meta->{BUILD} || [] };
+        }
 
         return $self;
     }
 
-    sub BUILDALL {
-        $_->(@_) for @{ $Mite::META{ ref( $_[0] ) }{BUILD} || [] };
+    sub DESTROY {
+        my $self  = shift;
+        my $class = ref($self) || $self;
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        my $in_global_destruction =
+          defined ${^GLOBAL_PHASE}
+          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
+          : Devel::GlobalDestruction::in_global_destruction();
+        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
+            my $e = do {
+                local ( $?, $@ );
+                eval { $demolisher->( $self, $in_global_destruction ) };
+                $@;
+            };
+            no warnings 'misc';    # avoid (in cleanup) warnings
+            die $e if $e;          # rethrow
+        }
+        return;
     }
 
     sub __META__ {
         no strict 'refs';
-        require mro;
-        my $class      = shift;
+        my $class = shift;
+        $class = ref($class) || $class;
         my $linear_isa = mro::get_linear_isa($class);
         return {
             BUILD => [
@@ -80,23 +92,35 @@ q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::M
             ],
             DEMOLISH => [
                 map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } reverse @$linear_isa
+                  map { "$_\::DEMOLISH" } @$linear_isa
             ],
             HAS_BUILDARGS => $class->can('BUILDARGS'),
         };
     }
 
+    sub DOES {
+        my ( $self, $role ) = @_;
+        our %DOES;
+        return $DOES{$role} if exists $DOES{$role};
+        return 1            if $role eq __PACKAGE__;
+        return $self->SUPER::DOES($role);
+    }
+
+    sub does {
+        shift->DOES(@_);
+    }
+
     my $__XS = !$ENV{MITE_PURE_PERL}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for cards
-    *cards = sub {
+    sub cards {
         @_ > 1
           ? require Carp
           && Carp::croak("cards is a read-only attribute of @{[ref $_[0]]}")
           : (
-            exists( $_[0]{q[cards]} ) ? $_[0]{q[cards]} : (
-                $_[0]{q[cards]} = do {
+            exists( $_[0]{"cards"} ) ? $_[0]{"cards"} : (
+                $_[0]{"cards"} = do {
                     my $default_value = $_[0]->_build_cards;
                     do {
 
@@ -120,14 +144,17 @@ q[Type check failed in constructor: cards should be ArrayRef[InstanceOf["Acme::M
                       or do {
                         require Carp;
                         Carp::croak(
-q[Type check failed in default: cards should be ArrayRef[InstanceOf["Acme::Mitey::Cards::Card"]]]
+                            sprintf
+                              "Type check failed in default: %s should be %s",
+                            "cards",
+                            "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]"
                         );
                       };
                     $default_value;
                 }
             )
           );
-    };
+    }
 
     1;
 }
